@@ -4,7 +4,7 @@ use DBIx::Class::Candy -base => 'A::Schema::Result';
 
 table 'artists';
 
-column id => {
+primary_column id => {
    data_type => 'int',
    is_auto_increment => 1,
 };
@@ -15,8 +15,6 @@ has_column name => (
    is_nullable => 1,
 );
 
-primary_key 'id';
-
 has_many albums => 'A::Schema::Result::Album', 'artist_id';
 
 1;
